pub struct AutoloadEntry {
pub binary_mtime_at_cache: i64,
pub cached_at_secs: i64,
pub chunk_blob: Vec<u8>,
}Fields
binary_mtime_at_cache: i64cached_at_secs: i64chunk_blob: Vec<u8>Trait Implementations
Sourceimpl Archive for AutoloadEntry
impl Archive for AutoloadEntry
Sourcetype Archived = ArchivedAutoloadEntry
type Archived = ArchivedAutoloadEntry
The archived representation of this type. Read more
Sourcetype Resolver = AutoloadEntryResolver
type Resolver = AutoloadEntryResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for AutoloadEntry
impl Clone for AutoloadEntry
Sourcefn clone(&self) -> AutoloadEntry
fn clone(&self) -> AutoloadEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AutoloadEntry
impl Debug for AutoloadEntry
Sourceimpl<__D: Fallible + ?Sized> Deserialize<AutoloadEntry, __D> for Archived<AutoloadEntry>
impl<__D: Fallible + ?Sized> Deserialize<AutoloadEntry, __D> for Archived<AutoloadEntry>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<AutoloadEntry, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<AutoloadEntry, __D::Error>
Deserializes using the given deserializer