pub struct AutoloadShard {
pub header: ShardHeader,
pub entries: HashMap<String, AutoloadEntry>,
}Fields
header: ShardHeaderentries: HashMap<String, AutoloadEntry>Trait Implementations
Sourceimpl Archive for AutoloadShard
impl Archive for AutoloadShard
Sourcetype Archived = ArchivedAutoloadShard
type Archived = ArchivedAutoloadShard
The archived representation of this type. Read more
Sourcetype Resolver = AutoloadShardResolver
type Resolver = AutoloadShardResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for AutoloadShard
impl Clone for AutoloadShard
Sourcefn clone(&self) -> AutoloadShard
fn clone(&self) -> AutoloadShard
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AutoloadShard
impl Debug for AutoloadShard
Sourceimpl<__D: Fallible + ?Sized> Deserialize<AutoloadShard, __D> for Archived<AutoloadShard>where
ShardHeader: Archive,
Archived<ShardHeader>: Deserialize<ShardHeader, __D>,
HashMap<String, AutoloadEntry>: Archive,
Archived<HashMap<String, AutoloadEntry>>: Deserialize<HashMap<String, AutoloadEntry>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<AutoloadShard, __D> for Archived<AutoloadShard>where
ShardHeader: Archive,
Archived<ShardHeader>: Deserialize<ShardHeader, __D>,
HashMap<String, AutoloadEntry>: Archive,
Archived<HashMap<String, AutoloadEntry>>: Deserialize<HashMap<String, AutoloadEntry>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<AutoloadShard, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<AutoloadShard, __D::Error>
Deserializes using the given deserializer