_call_function

Function _call_function 

pub fn _call_function(args: &[String]) -> i32
_call_function — invoke a named shell function with the rest of the args, storing its exit status under the param named by $1. Returns 0 if invoked, 1 if the named fn doesn’t exist.