pub fn run_logout_scripts()Expand description
Source the selected drop-in’s logout files on the way out of a login
shell. Called from zexit, where zsh reads .zlogout.
pub fn run_logout_scripts()Source the selected drop-in’s logout files on the way out of a login
shell. Called from zexit, where zsh reads .zlogout.