Module modentry

Module modentry 

Module entry point dispatch

Port from zsh/Src/modentry.c (43 lines)

In C, this is the dlopen entry point that dispatches setup/boot/cleanup/finish calls to loaded modules. In Rust, all modules are statically compiled, so this provides the ModuleLifecycle trait dispatch instead.

Enums

ModOp
Module entry operations (from modentry.c boot parameter)

Functions

modentry
Dispatch a module lifecycle operation (from modentry.c modentry)