pub fn par_cmd_wordcode(cmplx: &mut i32, zsh_construct: i32) -> boolExpand description
Port of par_cmd(int *cmplx, int zsh_construct) from
Src/parse.c:958-1085. Parses leading + trailing redirs and
dispatches on the current token to the right par_* builder.
Returns false only when no command was emitted (no redirs +
par_simple returned 0).
Port of par_cmd(int *cmplx, int zsh_construct) from
Src/parse.c:957-1077.