highlight_shell

Function highlight_shell 

pub fn highlight_shell(
    buff: &str,
    color: &mut Vec<HighlightSpec>,
    ctx: &OperationContext,
    io_ok: bool,
    cursor: Option<usize>,
)
fish:93-113 — Perform syntax highlighting for the shell commands in buff. The result is stored in the color array as a HighlightSpec for each character in buff.

buffstr: the buffer (metafied, as the ZLE metaline) on which to perform syntax highlighting; ctx: cancellation check; io_ok: if set, allow IO which may block — e.g. invalid commands may be detected; cursor: cursor position in the commandline.