pub struct HighlightColorResolver { /* private fields */ }Expand description
fish:131-138 — highlight_color_resolver_t resolves highlight specs (like “a command”) to actual attributes. It maintains a cache with no invalidation mechanism. The lifetime of these should typically be one screen redraw.
Implementations
Sourceimpl HighlightColorResolver
impl HighlightColorResolver
Sourcepub fn resolve_spec(&mut self, highlight: &HighlightSpec) -> zattr
pub fn resolve_spec(&mut self, highlight: &HighlightSpec) -> zattr
fish:148-162 — Return a packed attribute for a given highlight spec.
Sourcepub fn resolve_spec_uncached(highlight: &HighlightSpec) -> zattr
pub fn resolve_spec_uncached(highlight: &HighlightSpec) -> zattr
fish:163-219 — resolve_spec_uncached.