pub fn select_parse_reply(reply: &str, items: &[String]) -> Option<String>
Parse select reply (from loop.c execselect)
Given the user’s input and the item list, returns the selected item or None if the input is invalid.